@@ -292,6 +292,10 @@ class Base(Controller):
                 # TODO: probably better as mandatory
                 "help" : "Which lines from the selected history to show/save",
                 "action" : "store"
+            }),
+            (['-e'],{
+                "help": "Which terns to exclude separated by commas",
+                "action": "store"
             })
         ]
     )
@@ -300,7 +304,9 @@ class Base(Controller):
             from ..ext.hist import hist_tail
             import pprint as pp
             n_lines = int(self.app.pargs.n or 20)
-            pp.pprint(hist_tail(n_lines))
+            excluded_terms = self.app.pargs.e or []
+            if isinstance(excluded_terms, str): excluded_terms = excluded_terms.split(',')
+            pp.pprint(hist_tail(n_lines, excluded_terms))
         else: 
             from ..ext.hist import hist_show
             print(hist_show(self.app.pargs.n))
@@ -481,7 +487,7 @@ class Base(Controller):
         help='All Github related operations',
         arguments=[
              (['action'],{
-                "help" : "To show one of {forks, contrib}.",
+                "help" : "To show one of {forks, contrib, stash}.",
                 "action" : "store"
             }),
             (['-url'],{
@@ -497,7 +503,9 @@ class Base(Controller):
         if self.app.pargs.action=='contrib':
             from ..ext.github import find_contributors
             print(find_contributors(self.app.pargs.url))
-
+        if self.app.pargs.action=='diff':
+            from ..ext.github import dir_diff
+            pp(dir_diff(self.app.pargs.url))
 
     @ex(
         help='Manage TODOs using Google Keep',
