@@ -1,8 +1,9 @@
 # pip install github3.py
 import github3
 import pandas as pd
-import sys
+import sys, os
 import subprocess as sp
+import json
 
 def init():
     git_config = sp.run(["git","config","-l"], capture_output=True).stdout
@@ -42,4 +43,26 @@ def find_contributors(repo_url: str):
     c = SshConfig(f)
 
     g = github3.login(gh_username, gh_password)
-    r = g.repository(user, repo)
\ No newline at end of file
+    r = g.repository(user, repo)
+
+def dir_diff(cwd: str) -> json:
+    # get all dirs in cwd
+    output = []
+    all_directories = os.listdir(cwd)
+
+    # check that all are directories
+    dirs_only = [ d for d in all_directories if len(d.split('.'))==1 and d!='swap2' ]
+
+    for dir in dirs_only:
+        cwd = os.path.abspath(dir)
+        git_stash = sp.run(["git","diff"], cwd=cwd, capture_output=True)
+        output.append([cwd, git_stash.stdout.decode()])
+
+    diff_df = pd.DataFrame(output, columns=['dir','diff'])
+    non_empty_diffs = diff_df.loc[diff_df['diff'].str.len() > 0]
+    dict_diffs = non_empty_diffs.to_dict(orient='index')
+
+    # map 'dir' value to key in dict_diffs
+    dict_diffs = {v['dir']:v['diff'] for k,v in dict_diffs.items()}
+
+    return dict_diffs
\ No newline at end of file
