@@ -20,15 +20,13 @@ def dt_conv(l: str):
     try:
         # TODO: correct timezone? why does midnight show up as 4 pm?
         pd_dt_repr = pd.to_datetime(dt.datetime.fromtimestamp(int(l[1].strip())))
-        # ret_val = '_'.join(str(pd_dt_repr).split(' ')[::-1])
         return  humanize.naturaldelta(pd_dt_repr)
     except ValueError as e:
         # TODO: why does this occur
-        # print(e)
         pass
 
 
-def filter_term(term: tuple):
+def filter_term(term: tuple, excluded_terms = FILTER_TERMS):
     # Logic: all filter terms need to _not_ match
     if 'cd' in term[0][:2]:
         try:
@@ -39,9 +37,11 @@ def filter_term(term: tuple):
         except:
             print(f"Error with {term[0]}")
 
-    return all([ft not in term[0] for ft in FILTER_TERMS])
+    return all([ft not in term[0] for ft in excluded_terms])
 
-def hist_tail(n_lines=20):
+def hist_tail(n_lines=20, excluded_terms = []):
+    excluded_terms = FILTER_TERMS + excluded_terms
+    
     shell = os.environ['SHELL'].split('/')[-1]
 
     if shell=='sh': shell = 'bashrc'
@@ -64,7 +64,7 @@ def hist_tail(n_lines=20):
     parsed = list(zip(parsed_commands, parsed_dt))
 
     # remove FILTER_TERMS 
-    cmds = [ t for t in parsed if filter_term(t) ]
+    cmds = [ t for t in parsed if filter_term(t, excluded_terms) ]
 
     # identify Levenstein distance
     lev_dist = [ dist(cmds[i][0],cmds[i+1][0]) for i in range(len(cmds)-1) ]
